@@ -11,19 +11,20 @@ class IndexExecuter:
         self.start_date = input('Enter Start date in yyyy-mm-dd format: ') or str(today_date - timedelta(90))
         self.end_date = input('Enter End date in yyyy-mm-dd format: ') or str(today_date)
         self.indice_name = input('Enter target indice name for crop classification eg: ndvi / fcc: ') or 'ndvi'
-        self.cloud_threshold = int(input('Enter cloud threshold in percentage for sentinel 2 tiles: ')) or 10
-        self.data_interval = int(input('Enter Number of days interval for sentinel2 data & indice ts:')) or 15
+        self.cloud_threshold = int(input('Enter cloud threshold in percentage for sentinel 2 tiles: ') or 10)
+        self.data_interval = int(input('Enter Number of days interval for sentinel2 data & indice ts:') or 15)
         self.shape_file_path = input('provide complete path of shapefile, Skip if passing bbox') or None
         self.bbox = input('provide valid bounding box in order - minx miny maxx maxy! Skip if '
                           'passing shapefile') or None
-        self.width = int(input('Enter width of array if input is raster: ')) or None
-        self.height = int(input('Enter height of array if input is raster:')) or None
-        self.shape_file_path = self.shape_file_path.replace('\\', '/')
+        self.width = int(input('Enter width of array if input is raster or bbox: ')) or None
+        self.height = int(input('Enter height of array if input is raster or bbox:')) or None
         self.output_dir_path = output_dir_path
         self.s2 = sentinel2.Sentinel2()
         self.idc = indices.indice()
 
     def get_layer_stack(self):
+        if self.shape_file_path:
+            self.shape_file_path = self.shape_file_path.replace('\\', '/')
         bounds = None
         if self.bbox:
             bounds = tuple(float(item) for item in self.bbox.split(' '))
